#!/usr/bin/env python
#
# Author: Mike McKerns (mmckerns @caltech and @uqfoundation)
# Copyright (c) 2018-2023 The Uncertainty Quantification Foundation.
# License: 3-clause BSD.  The full license text is available at:
#  - https://github.com/uqfoundation/dill/blob/master/LICENSE
"""
to run this test suite, first build and install `dill`.

  $ python setup.py build
  $ python setup.py install


then run the tests with:

  $ python -m dill.tests


or, if `nose` is installed:

  $ nosetests  

"""
